/*
 *  SingIt Lyrics Displayer
 *  Copyright (C) 2000 - 2002 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#ifndef __SINGIT_DIALOGS_H__
#define __SINGIT_DIALOGS_H__

#include <singit_macros.h>

#ifdef __cplusplus
extern "C" {
#endif // __cplusplus

void singit_editor_show();
void singit_config_show();
void singit_config_show_page(gint page);
void singit_about_show();
void singit_about_show_page(gint page);
void singit_tag_manager_show();

#ifdef __cplusplus
}
#endif // __cplusplus

#endif // __SINGIT_DIALOGS_H__
